vfbLib.typing.GlyphBitmapDict
=============================

.. currentmodule:: vfbLib.typing

.. autoclass:: GlyphBitmapDict
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphBitmapDict.__init__
      ~GlyphBitmapDict.clear
      ~GlyphBitmapDict.copy
      ~GlyphBitmapDict.fromkeys
      ~GlyphBitmapDict.get
      ~GlyphBitmapDict.items
      ~GlyphBitmapDict.keys
      ~GlyphBitmapDict.pop
      ~GlyphBitmapDict.popitem
      ~GlyphBitmapDict.setdefault
      ~GlyphBitmapDict.update
      ~GlyphBitmapDict.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlyphBitmapDict.ppm
      ~GlyphBitmapDict.origin
      ~GlyphBitmapDict.adv
      ~GlyphBitmapDict.size_pixels
      ~GlyphBitmapDict.bitmap
   
   